'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var equalString = function equalString() {
  var first = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var second = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';

  return first.toLowerCase() === second.toLowerCase();
};

var VueMockPlugin = {
  install: function install(Vue, opts) {

    if (!Vue.http) return;

    Vue.http.interceptors.unshift(function (request, next) {

      var match = opts.find(function (m) {
        return equalString(request.method, m.method) && equalString(request.url, m.url);
      });

      if (!match) {

        next(request.respondWith({
          status: 404,
          statusText: 'Not found'
        }));
      } else {

        var delay = match.delay || 2000;

        setTimeout(function () {

          var ret = match.response(request);

          if (ret) {
            next(request.respondWith(ret, {
              status: 200,
              statusText: 'Ok'
            }));
          } else {
            next(request.respondWith({
              status: 500,
              statusText: 'Server Error'
            }));
          }
        }, delay);
      }
    });
  }
};

if (typeof window !== 'undefined' && window.Vue) {
  window.Vue.use(VueMockPlugin);
}

exports.default = VueMockPlugin;