const equalString = function (first = '', second = '') {
  return first.toLowerCase() === second.toLowerCase()
}

const VueMockPlugin = {

  install(Vue, opts) {

    if (!Vue.http) return

    Vue.http.interceptors.unshift((request, next) => {

      const match = opts.find(m => equalString(request.method, m.method) && equalString(request.url, m.url))

      if (!match) {

        next(
          request.respondWith({
            status: 404,
            statusText: 'Not found'
          })
        )

      } else {

        const delay = match.delay || 2000

        setTimeout(() => {

          const ret = match.response(request);

          if (ret) {
            next(
              request.respondWith(ret, {
                status: 200,
                statusText: 'Ok'
              })
            )
          } else {
            next(
              request.respondWith({
                status: 500,
                statusText: 'Server Error'
              })
            )
          }

        }, delay);
      }
    })
  }
}

if (typeof window !== 'undefined' && window.Vue) {
  window.Vue.use(VueMockPlugin)
}

export default VueMockPlugin
